@@ -1,3 +1,4 @@
+"""utility class for parsing and manipulating datetime objects"""
 from datetime import datetime
 from datetime import timedelta
 from typing import List, Union
@@ -19,6 +20,11 @@ class datetimeManager:
     def __init__(self,
                  string_format: str = _default_datetime_format,
                  ):
+        """
+        utility class for parsing and manipulating datetime objects
+
+        :param string_format: datetime string format to use for parsing
+        """
         self._string_format = string_format
 
     @property
@@ -63,6 +69,7 @@ class datetimeManager:
     def relative_datetime(cls,
                           datetime_objects: List[datetime],
                           units: Union[_unit_seconds, _unit_minutes, _unit_hours] = None,
+                          rounding: int = None,
                           ) -> List[timedelta]:
         """
         Convert an array of datetime objects that are absolute times, and return an array where all the times in the
@@ -70,6 +77,7 @@ class datetimeManager:
 
         :param datetime_objects: a list of datetime objects
         :param units: one of _unit_seconds, _unit_minutes, or _unit_hours
+        :param int, rounding: the number of decimal places to round to
         :return:
         """
         # takes a list of datetime objects, and makes all the values relative to the first object in the list
@@ -100,6 +108,10 @@ class datetimeManager:
                                             range(len(array_of_relative_x_in_seconds))]
             array_of_relative_datetime_objects = array_of_relative_x_in_hours
 
+        if rounding is not None:
+            array_of_relative_datetime_objects = [round(datetime_obj, rounding) for datetime_obj in
+                                                  array_of_relative_datetime_objects]
+
         return array_of_relative_datetime_objects
 
     def now_string(self) -> str:
@@ -113,6 +125,9 @@ class datetimeManager:
 def array_of_str_to_array_of_datetime_objects(list_of_string_values,
                                               datetime_format: str = '%Y_%m_%d_%H_%M_%S',
                                               ) -> List[datetime]:
+    """
+    Legacy passthrough for deprecated function. Use the datetimeManager class method instead.
+    """
     warnings.warn(  # v3.7.1
         'This method has been deprecated, use the class method in the datetimeManager class; use that instead',
         DeprecationWarning,
@@ -123,6 +138,9 @@ def array_of_str_to_array_of_datetime_objects(list_of_string_values,
 def array_of_datetime_objects_to_array_of_relative_datetime_objects(array_of_datetime_objects,
                                                                     units,
                                                                     ) -> List[timedelta]:
+    """
+    Legacy passthrough for deprecated function. Use the datetimeManager class method instead.
+    """
     warnings.warn(  # v3.7.1
         'This method has been deprecated, use the class method in the datetimeManager class; use that instead',
         DeprecationWarning,
