@@ -560,10 +560,7 @@ class RTMSlackBot(SlackBot):
             auto_reconnect=auto_reconnect,
             ping_interval=ping_interval,
         )
-        slack.RTMClient.on(
-            event='message',
-            callback=self.run_on_message,
-        )
+        self.register_message_catch(self.run_on_message)
         slack.RTMClient.on(
             event='error',
             callback=self.run_on_error,
@@ -625,6 +622,9 @@ class RTMSlackBot(SlackBot):
         """starts the RTM monitor thread"""
         self.rtm_client.start()
 
+    def register_message_catch(self, callback_fn):
+        slack.RTMClient.on(event='message', callback=callback_fn)
+
 
 class WebClientOverride(contextlib.AbstractContextManager):
     def __init__(self,
